pub struct TransactionSequencer<C, R> {
sender: Sender<(R, Sender<Result<TxId>>)>,
client: Arc<C>,
}Expand description
Takes care of sequencing transactions, nonce management, and submitting the transactions to the blockchain in-order.
This object is meant to be a singleton and cannot be cloned.
Fields
sender: Sender<(R, Sender<Result<TxId>>)>client: Arc<C>Implementations
Sourceimpl<C, R> TransactionSequencer<C, R>where
C: BlokliQueryClient + BlokliTransactionClient + Send + Sync + 'static,
R: SignableTransaction + Send + Sync + 'static,
impl<C, R> TransactionSequencer<C, R>where
C: BlokliQueryClient + BlokliTransactionClient + Send + Sync + 'static,
R: SignableTransaction + Send + Sync + 'static,
pub fn new(signer: ChainKeypair, client: Arc<C>) -> Self
Sourceimpl<C, R> TransactionSequencer<C, R>
impl<C, R> TransactionSequencer<C, R>
Sourcepub async fn enqueue_transaction(
&self,
transaction: R,
timeout_until_finalized: Duration,
) -> Result<impl Future<Output = Result<Transaction>>>
pub async fn enqueue_transaction( &self, transaction: R, timeout_until_finalized: Duration, ) -> Result<impl Future<Output = Result<Transaction>>>
Adds the transaction to the TransactionSequencer queue.
The timeout_until_finalized is a total time until the TX is submitted and either confirmed or rejected.